@@ -75,7 +75,7 @@ class Timegrid:
         if not end is None:            
             self.end   = pd.Timestamp(end)
 
-        # use reference and ignore start/end
+        # use reference TG and ignore start/end - then filter
         if ref_timegrid is not None:
             if self.start is None:
                 self.start = ref_timegrid.start
@@ -90,15 +90,55 @@ class Timegrid:
                 if self.end.tzinfo is None:
                     self.end = pd.Timestamp(self.end, tz = self.tz)
                 else:
-                    self.end = pd.Timestamp(self.end)                
-            I = (ref_timegrid.timepoints>=self.start) & (ref_timegrid.timepoints<self.end)         
-            self.I = ref_timegrid.I[I]
-            self.timepoints = ref_timegrid.timepoints[I]
-            self.dt = ref_timegrid.dt[I]
-            self.Dt = ref_timegrid.Dt[I]
-            self.T = len(self.timepoints)
-            if hasattr(ref_timegrid,'discount_factors'):
-                self.discount_factors = ref_timegrid.discount_factors[I]
+                    self.end = pd.Timestamp(self.end)          
+            # restricted timegrid is generated by filtering the main timegrid
+            if freq == ref_timegrid.freq:
+                I = (ref_timegrid.timepoints>=self.start) & (ref_timegrid.timepoints<self.end)         
+                self.I = ref_timegrid.I[I]
+                self.timepoints = ref_timegrid.timepoints[I]
+                self.dt = ref_timegrid.dt[I]
+                self.Dt = ref_timegrid.Dt[I]
+                self.T = len(self.timepoints)
+                if hasattr(ref_timegrid,'discount_factors'):
+                    self.discount_factors = ref_timegrid.discount_factors[I]
+                # if  frequency is different from reference do further filtering
+            else:
+                try:
+                    freq_a = pd.Timedelta(1, freq)
+                except:
+                    freq_a = pd.Timedelta(freq)
+                try:
+                    freq_p = pd.Timedelta(1, ref_timegrid.freq)
+                except:
+                    freq_p = pd.Timedelta(ref_timegrid.freq)                    
+                assert (freq_a >= freq_p), 'timegrid must have less/equal granular frequency than reference'
+                # generate more granular timegrid - all minor grid points in "right interval"  |->|->|->|
+                pts  = (pd.date_range(start=self.start, end = self.end, freq = freq, tz = self.tz))
+                self.I          = []
+                self.I_minor_in_major = [] # to contain the list of minor grid points in major grid
+                self.timepoints = []
+                self.dt         = []
+                self.Dt         = []                
+                if hasattr(ref_timegrid,'discount_factors'):
+                    self.discount_factors = []
+                for a,b in zip(pts[0:-1], pts[1:]):
+                    I = (ref_timegrid.timepoints >= a) & (ref_timegrid.timepoints < b)
+                    self.I_minor_in_major.append(ref_timegrid.I[I])
+                    myI = ref_timegrid.I[I].min() # last minor grid in major grid
+                    self.I.append(myI)
+                    self.dt.append(ref_timegrid.dt[I].sum())
+                    self.Dt.append(ref_timegrid.Dt[myI])
+                    self.timepoints.append(ref_timegrid.timepoints[myI])
+                    if hasattr(ref_timegrid,'discount_factors'):
+                        self.discount_factors.append(ref_timegrid.discount_factors[myI])      
+                self.I          = np.asarray(self.I)
+                self.timepoints = np.asarray(self.timepoints)
+                self.dt         = np.asarray(self.dt)
+                self.Dt         = np.asarray(self.Dt)
+                self.T          = len(self.timepoints)
+                if hasattr(ref_timegrid,'discount_factors'):
+                    self.discount_factors = np.asarray(self.discount_factors)
+                pass
         # no reference TG given
         else:
             if self.start.tzinfo is None:
@@ -106,12 +146,12 @@ class Timegrid:
             if self.end.tzinfo is None:
                 self.end = pd.Timestamp(self.end, tz = self.tz)
             assert self.start < self.end
-            timepoints = pd.date_range(start=self.start, end = self.end, freq = self.freq, tz = self.tz)
+            timepoints      = pd.date_range(start=self.start, end = self.end, freq = self.freq, tz = self.tz)
             self.timepoints = timepoints[0:-1] # specific time points of mesh
-            self.dt = (timepoints[1:]-timepoints[0:-1])/pd.Timedelta(1, self.main_time_unit) # time steps in mesh 
-            self.Dt = np.cumsum(self.dt) # total duration since start (in main time unit)
-            self.T = len(self.timepoints) #  number of time steps in mesh
-            self.I    = np.array(range(0,self.T))
+            self.dt         = (timepoints[1:]-timepoints[0:-1])/pd.Timedelta(1, self.main_time_unit) # time steps in mesh 
+            self.Dt         = np.cumsum(self.dt) # total duration since start (in main time unit)
+            self.T          = len(self.timepoints) #  number of time steps in mesh
+            self.I          = np.array(range(0,self.T))
 
             self.dt = self.dt.values
             self.Dt = self.Dt.values
@@ -126,16 +166,20 @@ class Timegrid:
         self.discount_factors =  1./d**(self.Dt*pd.Timedelta(1, self.main_time_unit)/pd.Timedelta(1, 'd')) 
 
 
-    def set_restricted_grid(self,start:dt.datetime = None, end:dt.datetime = None):
+    def set_restricted_grid(self,start:dt.datetime = None, end:dt.datetime = None, freq:bool = None):
         """ return dictionary of arrays restricted to start/end
             used typically for assets valid in restricted timeframe
         Args:
             start, end (dt.datetime): start and end of restricted arrays. Default to None --> full timegrid's start/end
+            freq (bool, optional):    frequency for restr. timegrid. may be chosen less granular than tg. Defaults to None
         """
         # if start/end not given, use those from timegrid
         if start is None: start = self.start
         if end   is None: end   = self.end
-        self.restricted = Timegrid(start, end, freq=self.freq, main_time_unit=self.main_time_unit, ref_timegrid = self)
+        if freq is None: # standard case
+            self.restricted = Timegrid(start, end, freq=self.freq, main_time_unit=self.main_time_unit, ref_timegrid = self)
+        else: # in case the restricted timegrid should have a different frequency:
+            self.restricted = Timegrid(start, end, freq=freq, main_time_unit=self.main_time_unit, ref_timegrid = self)
 
     def prep_date_dict(self, dd:dict):
         """ Using dicts with keys "start", "end" and "values" throughout. Could change to an own classe
